pub enum AuthenticationCLIError {
ParseUrlError(ParseError),
MissingPassword,
NoAuthenticationMethod,
PrefixDevBadMethod,
AnacondaOrgBadMethod,
S3BadMethod,
AnyhowError(Error),
AuthenticationStorageError(AuthenticationStorageError),
ReqwestError(Error),
JsonParseError(String),
UnauthorizedToken,
}Expand description
Authentication errors that can be returned by the AuthenticationCLIError
Variants
ParseUrlError(ParseError)
An error occurred when the input repository URL is parsed
MissingPassword
Basic authentication needs a username and a password. The password is missing here.
NoAuthenticationMethod
Authentication has not been provided in the input parameters.
PrefixDevBadMethod
Bad authentication method when using prefix.dev
AnacondaOrgBadMethod
Bad authentication method when using anaconda.org
S3BadMethod
Bad authentication method when using S3
AnyhowError(Error)
Wrapper for errors that are generated from the underlying storage system (keyring or file system)
AuthenticationStorageError(AuthenticationStorageError)
Wrapper for errors that are generated from the underlying storage system (keyring or file system)
ReqwestError(Error)
General http request error
JsonParseError(String)
JSON parsing failed
Token is unauthorized or invalid